summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2024-11-08 22:58:42 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2024-11-08 22:58:42 +0900
commit74b326cfa730971e2b329aeb893e7927612b1541 (patch)
tree3f0f2b1d4985be1df2aec87710a3f79a719c6af9
parent52e18e4dae77cff756ffdfd30ff7e18cd4d414fd (diff)
downloadsmb4k-74b326cfa730971e2b329aeb893e7927612b1541.tar.gz
smb4k-74b326cfa730971e2b329aeb893e7927612b1541.zip
Rename KUniqueApplication to TDEUniqueApplication
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
-rw-r--r--smb4k/main.cpp10
-rw-r--r--smb4k/smb4k.cpp2
2 files changed, 6 insertions, 6 deletions
diff --git a/smb4k/smb4k.cpp b/smb4k/smb4k.cpp
index 03a0828..2725447 100644
--- a/smb4k/smb4k.cpp
+++ b/smb4k/smb4k.cpp
@@ -32,7 +32,7 @@
#include <kstdaction.h>
#include <klibloader.h>
#include <tdemessagebox.h>
-#include <kuniqueapplication.h>
+#include <tdeuniqueapplication.h>
#include <kiconloader.h>
#include <tdeactionclasses.h>
#include <tdelocale.h>
diff --git a/smb4k/main.cpp b/smb4k/main.cpp
index fd0e51f..5563322 100644
--- a/smb4k/main.cpp
+++ b/smb4k/main.cpp
@@ -34,7 +34,7 @@
#include <kiconloader.h>
#include <dcopclient.h>
#include <tdeconfig.h>
-#include <kuniqueapplication.h>
+#include <tdeuniqueapplication.h>
#include <tdemessagebox.h>
#include <kstandarddirs.h>
@@ -102,17 +102,17 @@ int main( int argc, char *argv[] )
TDECmdLineArgs::init( argc, argv, &aboutData );
TDECmdLineArgs::addCmdLineOptions( options ); // Add our own options.
- KUniqueApplication::addCmdLineOptions();
+ TDEUniqueApplication::addCmdLineOptions();
- // This is not needed, because KUniqueApplication::start()
+ // This is not needed, because TDEUniqueApplication::start()
// is called directly before the application is executed, but
// we use it anyway. There is no performance impact.
- if ( !KUniqueApplication::start() )
+ if ( !TDEUniqueApplication::start() )
{
exit( 0 );
}
- KUniqueApplication app;
+ TDEUniqueApplication app;
// Check the current config file and remove it if it belongs to
// a version < 0.9.0.